PAWpySeed: pawpyseed.core.quad_check Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Variables
pawpyseed.core.quad_check Namespace Reference

## Variables
int | total = 0
int | numtheta = min( int(rstep*27/100), 26 )+3
| pts
| wts
| numphi = int((numtheta*2+2) * (1-pts[thetastep]**2)**0.5)

## Variable Documentation

pawpyseed.core.quad_check.numphi = int((numtheta*2+2) * (1-pts[thetastep]**2)**0.5)

int pawpyseed.core.quad_check.numtheta = min( int(rstep*27/100), 26 )+3

pawpyseed.core.quad_check.pts

int pawpyseed.core.quad_check.total = 0

pawpyseed.core.quad_check.wts